@@ -3,7 +3,6 @@ from .constants import Action
 from .redirects import HttpResponseSeeOther, redirect_303
 from .renderers import render_turbo_frame, render_turbo_stream
 from .response import (
-    TemplateFormResponse,
     TurboFrameResponse,
     TurboFrameTemplateResponse,
     TurboStreamIterableResponse,
@@ -17,7 +16,6 @@ from .template import render_turbo_frame_template, render_turbo_stream_template
 __all__ = [
     "Action",
     "HttpResponseSeeOther",
-    "TemplateFormResponse",
     "TurboFrame",
     "TurboFrameResponse",
     "TurboFrameTemplateResponse",
